@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -43,6 +43,7 @@
 #include <KHelpMenu>
 #include <AkonadiWidgets/controlgui.h>
 #include <MailCommon/MailKernel>
+#include <QAction>
 #include <QPushButton>
 
 ImportWizard::ImportWizard(WizardMode mode, QWidget *parent)
@@ -204,7 +205,7 @@ void ImportWizard::createAutomaticModePage()
 void ImportWizard::initializeImportModule()
 {
     const QVector<LibImportWizard::AbstractImporter *> lstPlugins = ImportMailPluginManager::self()->pluginsList();
-    for (LibImportWizard::AbstractImporter *abstractPlugin : qAsConst(lstPlugins)) {
+    for (LibImportWizard::AbstractImporter *abstractPlugin : lstPlugins) {
         if (abstractPlugin->foundMailer()) {
             abstractPlugin->setAbstractDisplayInfo(mAbstractDisplayInfo);
             mlistImport.insert(abstractPlugin->name(), abstractPlugin);
